@@ -273,14 +273,14 @@ namespace
     { "post-menu", NULL, N_("_Post") },
     { "help-menu", NULL, N_("_Help") },
     { "read-selected-group", "ICON_READ_MORE", N_("_Read Group"), NULL, N_("Read Selected Group"), G_CALLBACK(do_read_selected_group) },
-    { "mark-groups-read", GTK_STOCK_CLEAR, N_("_Mark Group _Read"), "<control><shift>M", N_("Mark Selected Groups Read"), G_CALLBACK(do_mark_selected_groups_read) },
-    { "delete-groups-articles", GTK_STOCK_DELETE, N_("_Delete Group's Articles"), "<control><shift>Delete", N_("Delete Selected Groups' Articles"), G_CALLBACK(do_clear_selected_groups) },
-    { "get-new-headers-in-selected-groups", "ICON_GET_SELECTED", N_("Get New _Headers in Selected Groups"), "A", N_("Get New Headers for Selected Groups"), G_CALLBACK(do_xover_selected_groups) },
+    { "mark-groups-read", GTK_STOCK_CLEAR, N_("_Mark Group _Read"), "<control><shift>M", N_("Mark Selected Group Read"), G_CALLBACK(do_mark_selected_groups_read) },
+    { "delete-groups-articles", GTK_STOCK_DELETE, N_("_Delete Group's Articles"), "<control><shift>Delete", N_("Delete Selected Group's Articles"), G_CALLBACK(do_clear_selected_groups) },
+    { "get-new-headers-in-selected-groups", "ICON_GET_SELECTED", N_("Get New _Headers in Selected Group"), "A", N_("Get New Headers for Selected Group"), G_CALLBACK(do_xover_selected_groups) },
     { "get-new-headers-in-subscribed-groups", "ICON_GET_SUBSCRIBED", N_("Get New _Headers in Subscribed Groups"), "<shift>A", N_("Get New Headers for Subscribed Groups"), G_CALLBACK(do_xover_subscribed_groups) },
     { "download-headers", "ICON_GET_DIALOG", N_("Get _Headers ..."), "", N_("Get Headers from Server"), G_CALLBACK(do_download_headers) },
     { "refresh-group-list", NULL, N_("Refresh Group List"), "", N_("Get a new Group list from the Server"), G_CALLBACK(do_refresh_groups) },
-    { "subscribe", NULL, N_("_Subscribe"), NULL, N_("Subscribe to Selected Groups"), G_CALLBACK(do_subscribe_selected_groups) },
-    { "unsubscribe", NULL, N_("_Unsubscribe"), NULL, N_("Unsubscribe from Selected Groups"), G_CALLBACK(do_unsubscribe_selected_groups) },
+    { "subscribe", NULL, N_("_Subscribe"), NULL, N_("Subscribe to Selected Group"), G_CALLBACK(do_subscribe_selected_groups) },
+    { "unsubscribe", NULL, N_("_Unsubscribe"), NULL, N_("Unsubscribe from Selected Group"), G_CALLBACK(do_unsubscribe_selected_groups) },
 
     { "save-articles", GTK_STOCK_SAVE, N_("_Save Articles ..."), "<shift>S", N_("Save Selected Articles ..."), G_CALLBACK(do_save_articles) },
     { "print", GTK_STOCK_PRINT, NULL, "<control>P", NULL, G_CALLBACK(do_print) },
