@@ -501,11 +501,11 @@ namespace
 void GUI :: do_save_articles ()
 {
   std::string path;
-  std::set<const Article*> selected_articles (_header_pane->get_full_selection ());
+  const std::vector<const Article*> articles (_header_pane->get_full_selection_v ());
 
   std::vector<Article> copies;
-  copies.reserve (selected_articles.size());
-  foreach_const (std::set<const Article*>, selected_articles, it)
+  copies.reserve (articles.size());
+  foreach_const (std::vector<const Article*>, articles, it)
     copies.push_back (**it);
 
   if (!copies.empty()) {
@@ -1351,7 +1351,7 @@ void GUI :: do_read_selected_group ()
     if (!total)
       activate_action ("download-headers");
     else if (_prefs.get_flag("get-new-headers-when-entering-group", true))
-      _queue.add_task (new TaskXOver (_data, group, TaskXOver::NEW));
+      _queue.add_task (new TaskXOver (_data, group, TaskXOver::NEW), Queue::TOP);
   }
 }
 void GUI :: do_mark_selected_groups_read ()
@@ -1370,7 +1370,7 @@ void GUI :: do_xover_selected_groups ()
 {
   const quarks_t group_names (_group_pane->get_full_selection ());
   foreach_const (quarks_t, group_names, it)
-    _queue.add_task (new TaskXOver (_data, *it, TaskXOver::NEW));
+    _queue.add_task (new TaskXOver (_data, *it, TaskXOver::NEW), Queue::TOP);
 }
 
 void GUI :: do_xover_subscribed_groups ()
@@ -1379,7 +1379,7 @@ void GUI :: do_xover_subscribed_groups ()
   quarks_v groups;
   _data.get_subscribed_groups (groups);
   foreach_const_r (quarks_v, groups, it)
-    _queue.add_task (new TaskXOver (_data, *it, TaskXOver::NEW));
+    _queue.add_task (new TaskXOver (_data, *it, TaskXOver::NEW), Queue::TOP);
 }
 
 void GUI :: do_download_headers ()
@@ -1512,13 +1512,11 @@ GUI :: set_queue_size_label (unsigned int running,
   char tip[128];
 
   // build the format strings
-  if (size == 0u) {
+  g_snprintf (tip, sizeof(tip), _("%u Tasks Running, %u Tasks Total"), running, size);
+  if (!size)
     g_snprintf (str, sizeof(str), _("No Tasks"));
-    *tip = '\0';
-  } else {
+  else
     g_snprintf (str, sizeof(str), _("Tasks: %u/%u"), running, size);
-    g_snprintf (tip, sizeof(tip), _("%u Tasks Running, %u Tasks Total"), running, size);
-  }
 
   // update the gui
   gtk_label_set_text (GTK_LABEL(_queue_size_label), str);
