@@ -232,7 +232,7 @@ HeaderPane :: render_score (GtkTreeViewColumn * col,
     bg = prefs.get_color_str ("score-color-high-bg", "yellow");
   } else if (score >= 1) {
     fg = prefs.get_color_str ("score-color-medium-fg", "black");
-    bg = prefs.get_color_str ("score-color-medium-bg", "red");
+    bg = prefs.get_color_str ("score-color-medium-bg", "cyan");
   } else if (score <= -9999) {
     fg = prefs.get_color_str ("score-color-ignored-fg", "dark grey");
     bg = prefs.get_color_str ("score-color-ignored-bg", "black");
@@ -679,14 +679,18 @@ HeaderPane :: on_tree_change (const Data::ArticleTree::Diffs& diffs)
   articles_t selectme;
   if (rows_added_or_removed)
   {
-    // figure out which articles to select when this is all done.
-    // if none of the current selections survive,
-    // be ready to select the next article...
-    articles_t tmp (get_full_selection ());
+    // we might need to change the selection after the update.
+    const articles_t tmp (get_full_selection ());
+
+    articles_t survivors;
     foreach_const (articles_t, tmp, it)
       if (!diffs.removed.count ((*it)->message_id))
-        selectme.insert (*it);
-    if (selectme.empty()) {
+        survivors.insert (*it);
+
+    if (survivors.empty()) {
+      // none of the current selections survive,
+      // so select the first article after the
+      // deleted ones...
       ArticleIsNotInSet tester (diffs.removed);
       RememberArticles actor (selectme);
       action_next_if (tester, actor);
@@ -761,17 +765,16 @@ const Article*
 HeaderPane :: get_first_selected_article () const
 {
    const Article * a (0);
-   std::set<const Article*> articles = get_full_selection ();
+   const std::set<const Article*> articles (get_full_selection ());
    if (!articles.empty())
      a = *articles.begin ();
    return a;
 }
 
-std::set<const Article*>
-HeaderPane :: get_full_selection () const
+std::vector<const Article*>
+HeaderPane :: get_full_selection_v () const
 {
-  debug ("get_full_selection");
-  std::set<const Article*> articles;
+  std::vector<const Article*> articles;
 
   // get a list of paths
   GtkTreeModel * model (0);
@@ -781,7 +784,7 @@ HeaderPane :: get_full_selection () const
      GtkTreePath * path (static_cast<GtkTreePath*>(l->data));
      GtkTreeIter iter;
      if (gtk_tree_model_get_iter (model, &iter, path))
-       articles.insert (get_article (model, &iter));
+       articles.push_back (get_article (model, &iter));
   }
 
   // cleanup
@@ -791,6 +794,18 @@ HeaderPane :: get_full_selection () const
   return articles;
 }
 
+std::set<const Article*>
+HeaderPane :: get_full_selection () const
+{
+  std::set<const Article*> articles;
+
+  const std::vector<const Article*> articles_v (get_full_selection_v());
+  foreach_const (std::vector<const Article*>, articles_v, it)
+    articles.insert (*it);
+
+  return articles;
+}
+
 void
 HeaderPane :: walk_and_collect (GtkTreeModel          * model,
                                 GtkTreeIter           * cur,
