@@ -92,8 +92,8 @@ NNTP_Pool :: check_in (NNTP * nntp, bool is_ok)
 
   // process the nntp if we have a match
   if (it != _pool_items.end()) {
+    --_active_count;
     if (is_ok) {
-      --_active_count;
       it->is_checked_in = true;
       it->last_active_time = time (NULL);
       fire_pool_has_nntp_available ();
@@ -108,12 +108,35 @@ NNTP_Pool :: check_in (NNTP * nntp, bool is_ok)
 /***
 ****
 ***/
+
 void
 NNTP_Pool :: on_server_limits_changed (const Quark& server, int max_connections)
 {
   assert (server == _server);
   _max_connections = max_connections;
-std::cerr << LINE_ID << " pool for " << server << " knows that it has a max of " << max_connections << " connections" << std::endl;
+}
+
+/***
+****
+***/
+
+void
+NNTP_Pool :: on_socket_created (const StringView& host, int port, bool ok, Socket* socket)
+{
+  if (!ok)
+  {
+    delete socket;
+    _connection_pending = false;
+  }
+  else
+  {
+    // okay, we at least we established a connection.
+    // now try to handshake and pass the buck to on_nntp_done().
+    std::string user, pass;
+    _server_info.get_server_auth (_server, user, pass);
+    NNTP * nntp = new NNTP (_server, user, pass, socket);
+    nntp->handshake (this); // 
+  }
 }
 
 void
@@ -169,34 +192,27 @@ NNTP_Pool :: get_counts (int& setme_active,
 void
 NNTP_Pool :: request_nntp ()
 {
-   int active, idle, pending, max;
-   get_counts (active, idle, pending, max);
+  int active, idle, pending, max;
+  get_counts (active, idle, pending, max);
 
 #if 0
-std::cerr << LINE_ID << "server " << _server << ", "
-          << "active: " << active << ' '
-          << "idle: " << idle << ' '
-          << "pending: " << pending << ' '
-          << "max: " << max << ' ' << std::endl;
+  std::cerr << LINE_ID << "server " << _server << ", "
+            << "active: " << active << ' '
+            << "idle: " << idle << ' '
+            << "pending: " << pending << ' '
+            << "max: " << max << ' ' << std::endl;
 #endif
 
-   if (!idle && !pending && active<max)
-   {
-      debug ("trying to create a socket");
+  if (!idle && !pending && active<max)
+  {
+    debug ("trying to create a socket");
 
-      std::string address;
-      int port;
-      _server_info.get_server_addr (_server, address, port);
-      Socket * sock (_socket_creator->create_socket (address, port));
-      if (sock != 0)
-      {
-         _connection_pending = true;
-         std::string user, pass;
-         _server_info.get_server_auth (_server, user, pass);
-         NNTP * nntp = new NNTP (_server, user, pass, sock);
-         nntp->handshake (this);
-      }
-   }
+    _connection_pending = true;
+    std::string address;
+    int port;
+    _server_info.get_server_addr (_server, address, port);
+    _socket_creator->create_socket (address, port, this);
+  }
 }
 
 /**
