@@ -239,6 +239,13 @@ namespace
 
     return ul;
   }
+
+  bool header_is_nonencoded_utf8 (const StringView& in)
+  {
+    const bool is_nonencoded (!in.strstr("=?"));
+    const bool is_utf8 (g_utf8_validate (in.str, in.len, 0));
+    return is_nonencoded && is_utf8;
+  }
 }
 
 void
@@ -257,7 +264,6 @@ TaskXOver :: on_nntp_line (NNTP               * nntp,
   bool ok = !l.empty();
   ok = ok && l.pop_token (tmp, '\t');    if (ok) number = view_to_ul (tmp);
   ok = ok && l.pop_token (subj, '\t');   if (ok) subj.trim ();
-if (line.strstr ("eagifg$7fo$1@sunflower.man.poznan.pl") != 0) std::cerr << LINE_ID << " [" << line << ']' << std::endl;
   ok = ok && l.pop_token (author, '\t'); if (ok) author.trim ();
   ok = ok && l.pop_token (date, '\t');   if (ok) date.trim ();
   ok = ok && l.pop_token (mid, '\t');    if (ok) mid.trim ();
@@ -291,36 +297,31 @@ if (line.strstr ("eagifg$7fo$1@sunflower.man.poznan.pl") != 0) std::cerr << LINE
   h = std::max (h, number);
 
   const char * fallback_charset = NULL; // FIXME
-  const std::string subject_utf8 = header_to_utf8 (subj, fallback_charset);
-  const std::string author_utf8 = header_to_utf8 (author, fallback_charset);
 
   ++_parts_so_far;
 
-  const time_t time = g_mime_utils_header_decode_date (date.str, NULL);
+  const Article * article = _data.xover_add (
+    nntp->_server, nntp->_group,
+    (header_is_nonencoded_utf8(subj) ? subj : header_to_utf8(subj,fallback_charset).c_str()),
+    (header_is_nonencoded_utf8(author) ? author : header_to_utf8(author,fallback_charset).c_str()),
+    date, mid, ref, bytes, lines, xref);
 
-  bool do_add = true;
-
-  if (_mode==DAYS && time<_days_cutoff) {
-    //std::cerr << LINE_ID << ' ' << time << " is less than " << _days_cutoff << " -- done with server " << _data.get_server_address(nntp->_server) << std::endl;
-    _server_to_minitasks[nntp->_server].clear ();
-    do_add = false;
-  }
-
-  // keep the article
-  if (do_add && _data.xover_add (nntp->_server, nntp->_group,
-                                 subject_utf8, author_utf8, time,
-                                 mid, ref, bytes, lines, xref))
+  if (article)
   {
     ++_articles_so_far;
 
-    // emit a status update
-    int& prev = _last_xover_number[nntp];
-    increment_step (number - prev);
-    prev = number;
-    if (!(_parts_so_far % 500))
-      set_status_va (_("%s (%lu parts, %lu articles)"), _short_group_name.c_str(), _parts_so_far, _articles_so_far);
+    // are we done?
+    if (_mode==DAYS && article->time_posted<_days_cutoff)
+      _server_to_minitasks[nntp->_server].clear ();
   }
 
+  // emit a status update
+  int& prev = _last_xover_number[nntp];
+  increment_step (number - prev);
+  prev = number;
+  if (!(_parts_so_far % 500))
+    set_status_va (_("%s (%lu parts, %lu articles)"), _short_group_name.c_str(), _parts_so_far, _articles_so_far);
+
   // cleanup
   g_free (buf);
 }
